@@ -38,12 +38,11 @@ static void	 gail_adjustment_get_maximum_value (AtkValue            *obj,
                                                     GValue              *value);
 static void	 gail_adjustment_get_minimum_value (AtkValue            *obj,
                                                     GValue              *value);
+static void	 gail_adjustment_get_minimum_increment (AtkValue        *obj,
+                                                    GValue              *value);
 static gboolean	 gail_adjustment_set_current_value (AtkValue            *obj,
                                                     const GValue        *value);
 
-static void      gail_adjustment_destroyed         (GtkAdjustment       *adjustment,
-                                                    GailAdjustment      *gail_adjustment);
-
 G_DEFINE_TYPE_WITH_CODE (GailAdjustment, gail_adjustment, ATK_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (ATK_TYPE_VALUE, atk_value_interface_init))
 
@@ -81,18 +80,18 @@ gail_adjustment_real_initialize (AtkObject *obj,
                                  gpointer  data)
 {
   GtkAdjustment *adjustment;
+  GailAdjustment *gail_adjustment;
 
   ATK_OBJECT_CLASS (gail_adjustment_parent_class)->initialize (obj, data);
 
   adjustment = GTK_ADJUSTMENT (data);
 
   obj->role = ATK_ROLE_UNKNOWN;
-  GAIL_ADJUSTMENT (obj)->adjustment = adjustment;
+  gail_adjustment = GAIL_ADJUSTMENT (obj);
+  gail_adjustment->adjustment = adjustment;
 
-  g_signal_connect_object (G_OBJECT (adjustment),
-                           "destroy",
-                           G_CALLBACK (gail_adjustment_destroyed),
-                           obj, 0);
+  g_object_add_weak_pointer (G_OBJECT (adjustment),
+                             (gpointer *) &gail_adjustment->adjustment);
 }
 
 static void	 
@@ -101,6 +100,7 @@ atk_value_interface_init (AtkValueIface *iface)
   iface->get_current_value = gail_adjustment_get_current_value;
   iface->get_maximum_value = gail_adjustment_get_maximum_value;
   iface->get_minimum_value = gail_adjustment_get_minimum_value;
+  iface->get_minimum_increment = gail_adjustment_get_minimum_increment;
   iface->set_current_value = gail_adjustment_set_current_value;
 }
 
@@ -118,7 +118,7 @@ gail_adjustment_get_current_value (AtkValue             *obj,
     return;
   }
 
-  current_value = adjustment->value;
+  current_value = gtk_adjustment_get_value (adjustment);
   memset (value,  0, sizeof (GValue));
   g_value_init (value, G_TYPE_DOUBLE);
   g_value_set_double (value,current_value);
@@ -138,7 +138,7 @@ gail_adjustment_get_maximum_value (AtkValue             *obj,
     return;
   }
 
-  maximum_value = adjustment->upper;
+  maximum_value = gtk_adjustment_get_upper (adjustment);
   memset (value,  0, sizeof (GValue));
   g_value_init (value, G_TYPE_DOUBLE);
   g_value_set_double (value, maximum_value);
@@ -158,12 +158,53 @@ gail_adjustment_get_minimum_value (AtkValue             *obj,
     return;
   }
 
-  minimum_value = adjustment->lower;
+  minimum_value = gtk_adjustment_get_lower (adjustment);
   memset (value,  0, sizeof (GValue));
   g_value_init (value, G_TYPE_DOUBLE);
   g_value_set_double (value, minimum_value);
 }
 
+static void
+gail_adjustment_get_minimum_increment (AtkValue        *obj,
+                                       GValue          *value)
+{
+  GtkAdjustment* adjustment;
+  gdouble minimum_increment;
+ 
+  adjustment = GAIL_ADJUSTMENT (obj)->adjustment;
+  if (adjustment == NULL)
+  {
+    /* State is defunct */
+    return;
+  }
+
+  if (gtk_adjustment_get_step_increment (adjustment) != 0 &&
+      gtk_adjustment_get_page_increment (adjustment) != 0)
+    {
+      if (ABS (gtk_adjustment_get_step_increment (adjustment)) < ABS (gtk_adjustment_get_page_increment (adjustment)))
+        minimum_increment = gtk_adjustment_get_step_increment (adjustment);
+      else
+        minimum_increment = gtk_adjustment_get_page_increment (adjustment);
+    }
+  else if (gtk_adjustment_get_step_increment (adjustment) == 0 &&
+           gtk_adjustment_get_page_increment (adjustment) == 0)
+    {
+      minimum_increment = 0;
+    }
+  else if (gtk_adjustment_get_step_increment (adjustment) == 0)
+    {
+      minimum_increment = gtk_adjustment_get_page_increment (adjustment);
+    }
+  else
+    {
+      minimum_increment = gtk_adjustment_get_step_increment (adjustment);
+    }
+
+  memset (value,  0, sizeof (GValue));
+  g_value_init (value, G_TYPE_DOUBLE);
+  g_value_set_double (value, minimum_increment);
+}
+
 static gboolean	 
 gail_adjustment_set_current_value (AtkValue             *obj,
                                    const GValue         *value)
@@ -187,14 +228,3 @@ gail_adjustment_set_current_value (AtkValue             *obj,
   else
     return FALSE;
 }
-
-static void
-gail_adjustment_destroyed (GtkAdjustment       *adjustment,
-                           GailAdjustment      *gail_adjustment)
-{
-  /*
-   * This is the signal handler for the "destroy" signal for the 
-   * GtkAdjustment. We set the  pointer location to NULL;
-   */
-  gail_adjustment->adjustment = NULL;
-}
