@@ -21,8 +21,6 @@
 
 #include <string.h>
 
-#undef GTK_DISABLE_DEPRECATED
-
 #include <gtk/gtk.h>
 #include "gaillabel.h"
 #include "gailwindow.h"
@@ -153,7 +151,7 @@ gail_label_real_initialize (AtkObject *obj,
   
   widget = GTK_WIDGET (data);
 
-  if (GTK_WIDGET_MAPPED (widget))
+  if (gtk_widget_get_mapped (widget))
     gail_label_init_text_util (gail_label, widget);
   else
     g_signal_connect (widget,
@@ -219,7 +217,7 @@ notify_name_change (AtkObject *atk_obj)
   GtkWidget *widget;
   GObject *gail_obj;
 
-  widget = GTK_ACCESSIBLE (atk_obj)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (atk_obj));
   if (widget == NULL)
     /*
      * State is defunct
@@ -423,7 +421,7 @@ gail_label_ref_state_set (AtkObject *accessible)
   GtkWidget *widget;
 
   state_set = ATK_OBJECT_CLASS (gail_label_parent_class)->ref_state_set (accessible);
-  widget = GTK_ACCESSIBLE (accessible)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (accessible));
 
   if (widget == NULL)
     return state_set;
@@ -441,7 +439,7 @@ gail_label_ref_relation_set (AtkObject *obj)
 
   g_return_val_if_fail (GAIL_IS_LABEL (obj), NULL);
 
-  widget = GTK_ACCESSIBLE (obj)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (obj));
   if (widget == NULL)
     /*
      * State is defunct
@@ -457,7 +455,7 @@ gail_label_ref_relation_set (AtkObject *obj)
        *
        * The relation set is not updated if the mnemonic widget is changed
        */
-      GtkWidget *mnemonic_widget = GTK_LABEL (widget)->mnemonic_widget;
+      GtkWidget *mnemonic_widget = gtk_label_get_mnemonic_widget (GTK_LABEL (widget));
 
       if (mnemonic_widget)
         {
@@ -502,7 +500,7 @@ gail_label_ref_relation_set (AtkObject *obj)
                         {
                           GtkWidget *temp_widget;
 
-                          temp_widget = GTK_BIN (list->data)->child;
+                          temp_widget = gtk_bin_get_child (GTK_BIN (list->data));
                           if (GTK_IS_BUTTON (temp_widget))
                             mnemonic_widget = temp_widget;
                         }
@@ -513,10 +511,6 @@ gail_label_ref_relation_set (AtkObject *obj)
                           temp_widget = GTK_WIDGET (list->data);
                           g_list_free (list);
                           list = gtk_container_get_children (GTK_CONTAINER (temp_widget));
-                          if (GTK_IS_COMBO (list->data))
-                            {
-                              mnemonic_widget = GTK_WIDGET (list->data);
-                            }
                         }
                     }
                   g_list_free (list);
@@ -552,7 +546,7 @@ gail_label_get_name (AtkObject *accessible)
        */
       GtkWidget *widget;
 
-      widget = GTK_ACCESSIBLE (accessible)->widget;
+      widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (accessible));
       if (widget == NULL)
         /*
          * State is defunct
@@ -599,7 +593,7 @@ gail_label_get_text (AtkText *text,
 
   const gchar *label_text;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return NULL;
@@ -629,7 +623,7 @@ gail_label_get_text_before_offset (AtkText         *text,
   GtkWidget *widget;
   GtkLabel *label;
   
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   
   if (widget == NULL)
     /* State is defunct */
@@ -653,7 +647,7 @@ gail_label_get_text_at_offset (AtkText         *text,
   GtkWidget *widget;
   GtkLabel *label;
  
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   
   if (widget == NULL)
     /* State is defunct */
@@ -677,7 +671,7 @@ gail_label_get_text_after_offset (AtkText         *text,
   GtkWidget *widget;
   GtkLabel *label;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   
   if (widget == NULL)
   {
@@ -699,7 +693,7 @@ gail_label_get_character_count (AtkText *text)
   GtkWidget *widget;
   GtkLabel  *label;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return 0;
@@ -721,7 +715,7 @@ gail_label_set_caret_offset (AtkText *text,
   GtkWidget *widget;
   GtkLabel  *label;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return 0;
@@ -730,7 +724,7 @@ gail_label_set_caret_offset (AtkText *text,
 
   if (gtk_label_get_selectable (label) &&
       offset >= 0 &&
-      offset <= g_utf8_strlen (label->text, -1))
+      offset <= g_utf8_strlen (gtk_label_get_text (label), -1))
     {
       gtk_label_select_region (label, offset, offset);
       return TRUE;
@@ -746,7 +740,7 @@ gail_label_get_n_selections (AtkText *text)
   GtkLabel  *label;
   gint start, end;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return 0;
@@ -771,7 +765,7 @@ gail_label_get_selection (AtkText *text,
   GtkWidget *widget;
   GtkLabel  *label;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return NULL;
@@ -807,7 +801,7 @@ gail_label_add_selection (AtkText *text,
   GtkLabel  *label;
   gint start, end;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return FALSE;
@@ -834,7 +828,7 @@ gail_label_remove_selection (AtkText *text,
   GtkLabel  *label;
   gint start, end;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return FALSE;
@@ -866,7 +860,7 @@ gail_label_set_selection (AtkText *text,
   GtkLabel  *label;
   gint start, end;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return FALSE;
@@ -900,9 +894,10 @@ gail_label_get_character_extents (AtkText      *text,
   GtkWidget *widget;
   GtkLabel *label;
   PangoRectangle char_rect;
+  const gchar *label_text;
   gint index, x_layout, y_layout;
  
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
 
   if (widget == NULL)
     /* State is defunct */
@@ -911,7 +906,8 @@ gail_label_get_character_extents (AtkText      *text,
   label = GTK_LABEL (widget);
   
   gtk_label_get_layout_offsets (label, &x_layout, &y_layout);
-  index = g_utf8_offset_to_pointer (label->text, offset) - label->text;
+  label_text = gtk_label_get_text (label);
+  index = g_utf8_offset_to_pointer (label_text, offset) - label_text;
   pango_layout_index_to_pos (gtk_label_get_layout (label), index, &char_rect);
   
   gail_misc_get_extents_from_pango_rectangle (widget, &char_rect, 
@@ -926,9 +922,10 @@ gail_label_get_offset_at_point (AtkText      *text,
 { 
   GtkWidget *widget;
   GtkLabel *label;
+  const gchar *label_text;
   gint index, x_layout, y_layout;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return -1;
@@ -939,15 +936,16 @@ gail_label_get_offset_at_point (AtkText      *text,
   index = gail_misc_get_index_at_point_in_layout (widget, 
                                               gtk_label_get_layout (label), 
                                               x_layout, y_layout, x, y, coords);
+  label_text = gtk_label_get_text (label);
   if (index == -1)
     {
       if (coords == ATK_XY_WINDOW || coords == ATK_XY_SCREEN)
-        return g_utf8_strlen (label->text, -1);
+        return g_utf8_strlen (label_text, -1);
 
       return index;  
     }
   else
-    return g_utf8_pointer_to_offset (label->text, label->text + index);  
+    return g_utf8_pointer_to_offset (label_text, label_text + index);
 }
 
 static AtkAttributeSet*
@@ -962,7 +960,7 @@ gail_label_get_run_attributes (AtkText        *text,
   GtkJustification justify;
   GtkTextDirection dir;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return NULL;
@@ -987,7 +985,7 @@ gail_label_get_run_attributes (AtkText        *text,
 
   at_set = gail_misc_layout_get_run_attributes (at_set,
                                                 gtk_label_get_layout (label),
-                                                label->text,
+                                                gtk_label_get_text (label),
                                                 offset,
                                                 start_offset,
                                                 end_offset);
@@ -1001,7 +999,7 @@ gail_label_get_default_attributes (AtkText        *text)
   GtkLabel *label;
   AtkAttributeSet *at_set = NULL;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return NULL;
@@ -1023,7 +1021,7 @@ gail_label_get_character_at_offset (AtkText	         *text,
   const gchar *string;
   gchar *index;
 
-  widget = GTK_ACCESSIBLE (text)->widget;
+  widget = gtk_accessible_get_widget (GTK_ACCESSIBLE (text));
   if (widget == NULL)
     /* State is defunct */
     return '\0';
