@@ -60,7 +60,7 @@ add_completion_test_page (GtkWidget   *assistant,
   GtkWidget *check;
   PageData *pdata;
 
-  page = gtk_vbox_new (0, FALSE);
+  page = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   check = gtk_check_button_new_with_label ("Complete");
 
   gtk_container_add (GTK_CONTAINER (page), gtk_label_new (text));
@@ -116,7 +116,7 @@ progress_timeout (GtkWidget *assistant)
 
   current_page = gtk_assistant_get_current_page (GTK_ASSISTANT (assistant));
   page = gtk_assistant_get_nth_page (GTK_ASSISTANT (assistant), current_page);
-  progress = GTK_BIN (page)->child;
+  progress = gtk_bin_get_child (GTK_BIN (page));
 
   value  = gtk_progress_bar_get_fraction (GTK_PROGRESS_BAR (progress));
   value += 0.1;
@@ -140,7 +140,7 @@ prepare_callback (GtkWidget *widget, GtkWidget *page)
     {
       GtkWidget *progress;
 
-      progress = GTK_BIN (page)->child;
+      progress = gtk_bin_get_child (GTK_BIN (page));
       gtk_assistant_set_page_complete (GTK_ASSISTANT (widget), page, FALSE);
       gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress), 0.0);
       gdk_threads_add_timeout (300, (GSourceFunc) progress_timeout, widget);
@@ -184,7 +184,7 @@ create_simple_assistant (GtkWidget *widget)
       gtk_assistant_set_page_complete (GTK_ASSISTANT (assistant), page, TRUE);
     }
 
-  if (!GTK_WIDGET_VISIBLE (assistant))
+  if (!gtk_widget_get_visible (assistant))
     gtk_widget_show (assistant);
   else
     {
@@ -277,7 +277,7 @@ create_generous_assistant (GtkWidget *widget)
                       G_CALLBACK (complete_cb), pdata);
     }
 
-  if (!GTK_WIDGET_VISIBLE (assistant))
+  if (!gtk_widget_get_visible (assistant))
     gtk_widget_show (assistant);
   else
     {
@@ -337,7 +337,7 @@ create_nonlinear_assistant (GtkWidget *widget)
 					   nonlinear_assistant_forward_page,
 					   NULL, NULL);
 
-      page = gtk_vbox_new (FALSE, 6);
+      page = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 
       button = gtk_radio_button_new_with_label (NULL, "branch A");
       gtk_box_pack_start (GTK_BOX (page), button, FALSE, FALSE, 0);
@@ -374,7 +374,7 @@ create_nonlinear_assistant (GtkWidget *widget)
       gtk_assistant_set_page_complete (GTK_ASSISTANT (assistant), page, TRUE);
     }
 
-  if (!GTK_WIDGET_VISIBLE (assistant))
+  if (!gtk_widget_get_visible (assistant))
     gtk_widget_show (assistant);
   else
     {
@@ -471,7 +471,7 @@ create_looping_assistant (GtkWidget *widget)
       gtk_assistant_set_page_complete (GTK_ASSISTANT (assistant), page, TRUE);
     }
 
-  if (!GTK_WIDGET_VISIBLE (assistant))
+  if (!gtk_widget_get_visible (assistant))
     gtk_widget_show (assistant);
   else
     {
@@ -513,11 +513,11 @@ create_full_featured_assistant (GtkWidget *widget)
       gtk_assistant_set_page_complete (GTK_ASSISTANT (assistant), page, TRUE);
 
 	 /* set a side image */
-	 pixbuf = gtk_widget_render_icon (page, GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG, NULL);
+	 pixbuf = gtk_widget_render_icon_pixbuf (page, GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
 	 gtk_assistant_set_page_side_image (GTK_ASSISTANT (assistant), page, pixbuf);
 
 	 /* set a header image */
-	 pixbuf = gtk_widget_render_icon (page, GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG, NULL);
+	 pixbuf = gtk_widget_render_icon_pixbuf (page, GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
 	 gtk_assistant_set_page_header_image (GTK_ASSISTANT (assistant), page, pixbuf);
 
       page = get_test_page ("Invisible page");
@@ -531,11 +531,11 @@ create_full_featured_assistant (GtkWidget *widget)
       gtk_assistant_set_page_complete (GTK_ASSISTANT (assistant), page, TRUE);
 
 	 /* set a header image */
-	 pixbuf = gtk_widget_render_icon (page, GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG, NULL);
+	 pixbuf = gtk_widget_render_icon_pixbuf (page, GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
 	 gtk_assistant_set_page_header_image (GTK_ASSISTANT (assistant), page, pixbuf);
     }
 
-  if (!GTK_WIDGET_VISIBLE (assistant))
+  if (!gtk_widget_get_visible (assistant))
     gtk_widget_show (assistant);
   else
     {
@@ -574,7 +574,7 @@ main (int argc, gchar *argv[])
   g_signal_connect (G_OBJECT (window), "delete-event",
 		    G_CALLBACK (gtk_false), NULL);
 
-  box = gtk_vbox_new (FALSE, 6);
+  box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_container_add (GTK_CONTAINER (window), box);
 
   for (i = 0; i < G_N_ELEMENTS (buttons); i++)
